==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Modify/Explode/ts/Explode_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>Dialog</name>
    <message>
        <location filename="../ExplodeDialog.ui" line="+14"/>
        <source>Dialog</source>
        <translation>Dialogo</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Arcs and Circles</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Archi e cerchi</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into line segments (fixed length)</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>in segmenti di linea (lunghezza fissa)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>into line segments (fixed angle)</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>in segmenti di linea (angolo fisso)</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Ellipses</source>
        <translation>Ellissi</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into polyline with arc segments</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>in polilinea con segmenti di arco</translation>
    </message>
    <message>
        <location line="+5"/>
        <location line="+16"/>
        <source>into polyline with line segments</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>in polilinea con segmenti di linea</translation>
    </message>
    <message>
        <location line="-8"/>
        <source>Splines</source>
        <translation>Spine</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Dimensions</source>
        <translation>Quote</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into lines, solids and texts</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>in linee, solidi e testi</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Hatches</source>
        <translation>Tratteggi</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into lines</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>in linee</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Blocks</source>
        <translation>&amp;Blocchi</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into entities</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>in entità</translation>
    </message>
</context>
<context>
    <name>Explode</name>
    <message>
        <location filename="../ExplodeInit.js" line="+2"/>
        <source>&amp;Explode</source>
        <translation>&amp;Esplodi</translation>
    </message>
    <message>
        <location filename="../Explode.js" line="+30"/>
        <source>Modify</source>
        <translation>Modifica</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Explode</source>
        <translation>Esplodi</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+133"/>
        <source>Spline segments:</source>
        <translation>Segmenti di spline:</translation>
    </message>
    <message>
        <location line="-7"/>
        <source>Ellipse segments (per full ellipse):</source>
        <translation>Segmenti di ellisse:</translation>
    </message>
    <message>
        <location line="-7"/>
        <source>Spline approximation tolerance:</source>
        <translation>Spline tolleranza:</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Modify/Explode/ts/Explode_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>Dialog</name>
    <message>
        <location filename="../ExplodeDialog.ui" line="+14"/>
        <source>Dialog</source>
        <translation>Dialogo</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Arcs and Circles</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Archi e cerchi</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into line segments (fixed length)</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>in segmenti di linea (lunghezza fissa)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>into line segments (fixed angle)</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>in segmenti di linea (angolo fisso)</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Ellipses</source>
        <translation>Ellissi</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into polyline with arc segments</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>in polilinea con segmenti di arco</translation>
    </message>
    <message>
        <location line="+5"/>
        <location line="+16"/>
        <source>into polyline with line segments</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>in polilinea con segmenti di linea</translation>
    </message>
    <message>
        <location line="-8"/>
        <source>Splines</source>
        <translation>Spine</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Dimensions</source>
        <translation>Quote</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into lines, solids and texts</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>in linee, solidi e testi</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Hatches</source>
        <translation>Tratteggi</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into lines</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>in linee</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Blocks</source>
        <translation>&amp;Blocchi</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into entities</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>in entità</translation>
    </message>
</context>
<context>
    <name>Explode</name>
    <message>
        <location filename="../ExplodeInit.js" line="+2"/>
        <source>&amp;Explode</source>
        <translation>&amp;Esplodi</translation>
    </message>
    <message>
        <location filename="../Explode.js" line="+30"/>
        <source>Modify</source>
        <translation>Modifica</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Explode</source>
        <translation>Esplodi</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+197"/>
        <source>Explode text glyphs to polylines</source>
        <translation>Esplodere testo delinea in polilinee</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Spline segments:</source>
        <translation>Segmenti di spline:</translation>
    </message>
    <message>
        <location line="-27"/>
        <source>Ellipse segments (per full ellipse):</source>
        <translation>Segmenti di ellisse:</translation>
    </message>
    <message>
        <location line="-7"/>
        <source>Explode splines to polylines with line segments</source>
        <translation>Explode spline in polilinee con segmenti di linea</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Explode multiline texts into multiple simple text blocks</source>
        <translation>Esploda i testi multilinea in più blocchi di testo semplici</translation>
    </message>
    <message>
        <location line="-31"/>
        <source>Spline approximation tolerance:</source>
        <translation>Spline tolleranza:</translation>
    </message>
</context>
</TS>
